@@ -104,6 +104,10 @@ def mysql2ora(col):
     return col
 
 
-COLTYPE_CONV["oracle"] = {"mysql": ora2mysql, "postgresql": ora2pg, "sqlite": ora2sqlite}
+COLTYPE_CONV["oracle"] = {
+    "mysql": ora2mysql,
+    "postgresql": ora2pg,
+    "sqlite": ora2sqlite,
+}
 COLTYPE_CONV["sqlite"] = {"oracle": sqlite2ora, "sqlite": sqlite2sqlite}
 COLTYPE_CONV["postgresql"] = {"oracle": pg2ora}
